@@ -48,11 +48,11 @@ pub mod macros {
     /// powf!(a,b) Example
     /// a to the power of b
     /// ```rust
-    /// let p = powf!(2.,2.);
+    /// let p = powff!(2.,2.);
     /// println!("{:?}",p);
     /// ```
     #[macro_export]
-    macro_rules! powf {
+    macro_rules! powff {
         ($a:expr,$b:expr) => {
             pow($a, $b)
         };
@@ -101,7 +101,7 @@ pub mod macros {
         };
     }
     pub fn run() {
-        // println!("{:?}", powf!(4., 2.));
+        println!("{:?}", powff!(4., 2.));
         // println!("{:?}", split_to_vec!("dnrops.gitee.io", "."));
         // println!("{:?}", args!()); //get argument Vec<String>
         // println!("{:?}", input!()); //get input from treminal to String
